package com.bonus.canteen.core.health.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.health.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.health.domain.HealthPersonMedicalReport;
import com.bonus.canteen.core.health.service.IHealthPersonMedicalReportService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 人员体检报告Controller
 * 
 * @author xsheng
 * @date 2025-05-25
 */
@Api(tags = "人员体检报告接口")
@RestController
@RequestMapping("/health_person_medical_report")
public class HealthPersonMedicalReportController extends BaseController {
    @Autowired
    private IHealthPersonMedicalReportService healthPersonMedicalReportService;

    /**
     * 查询人员体检报告列表
     */
    @ApiOperation(value = "查询人员体检报告列表")
    //@RequiresPermissions("health:report:list")
    @GetMapping("/list")
    public TableDataInfo list(HealthPersonMedicalReport healthPersonMedicalReport) {
        startPage();
        List<HealthPersonMedicalReport> list = healthPersonMedicalReportService.selectHealthPersonMedicalReportList(healthPersonMedicalReport);
        return getDataTable(list);
    }

    /**
     * 导出人员体检报告列表
     */
    @ApiOperation(value = "导出人员体检报告列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:report:export")
    @SysLog(title = "人员体检报告", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出人员体检报告")
    @PostMapping("/export")
    public void export(HttpServletResponse response, HealthPersonMedicalReport healthPersonMedicalReport) {
        List<HealthPersonMedicalReport> list = healthPersonMedicalReportService.selectHealthPersonMedicalReportList(healthPersonMedicalReport);
        ExcelUtil<HealthPersonMedicalReport> util = new ExcelUtil<HealthPersonMedicalReport>(HealthPersonMedicalReport.class);
        util.exportExcel(response, list, "人员体检报告数据");
    }

    /**
     * 获取人员体检报告详细信息
     */
    @ApiOperation(value = "获取人员体检报告详细信息")
    //@RequiresPermissions("health:report:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(healthPersonMedicalReportService.selectHealthPersonMedicalReportById(id));
    }

    /**
     * 新增人员体检报告
     */
    @ApiOperation(value = "新增人员体检报告")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:report:add")
    @SysLog(title = "人员体检报告", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增人员体检报告")
    @PostMapping
    public AjaxResult add(@RequestBody HealthPersonMedicalReport healthPersonMedicalReport) {
        try {
            return toAjax(healthPersonMedicalReportService.insertHealthPersonMedicalReport(healthPersonMedicalReport));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改人员体检报告
     */
    @ApiOperation(value = "修改人员体检报告")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:report:edit")
    @SysLog(title = "人员体检报告", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改人员体检报告")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody HealthPersonMedicalReport healthPersonMedicalReport) {
        try {
            return toAjax(healthPersonMedicalReportService.updateHealthPersonMedicalReport(healthPersonMedicalReport));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除人员体检报告
     */
    @ApiOperation(value = "删除人员体检报告")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:report:remove")
    @SysLog(title = "人员体检报告", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除人员体检报告")
	@PostMapping("/del/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(healthPersonMedicalReportService.deleteHealthPersonMedicalReportByIds(ids));
    }
}
